@@ -10,13 +10,14 @@ from inspect import isfunction
 from typing import Optional, Union, Callable
 
 from tqsdk import utils
-from tqsdk.api import TqApi, TqAccount, TqSim, TqKq
+from tqsdk.api import TqApi
 from tqsdk.backtest import TqBacktest
 from tqsdk.channel import TqChan
 from tqsdk.datetime import _is_in_trading_time
 from tqsdk.diff import _get_obj
 from tqsdk.lib.utils import _check_volume_limit, _check_direction, _check_offset, _check_volume, _check_price, \
     _check_offset_priority
+from tqsdk.tradeable import TqAccount, TqKq, TqSim
 
 
 class TargetPosTaskSingleton(type):
@@ -194,6 +195,8 @@ class TargetPosTask(object, metaclass=TargetPosTaskSingleton):
             # 2021-03-15 11:29:48 -     INFO - 时间: 2021-03-15 11:29:47.533515, 合约: SHFE.rb2106, 开平: OPEN, 方向: BUY, 手数: 3, 价格: 4687.000,手续费: 14.12
 
         """
+        if symbol.startswith("CZCE.CJ"):
+            raise Exception("红枣期货不支持创建 targetpostask、twap、vwap 任务，交易所规定该品种最小开仓手数为大于等于 4 手，这些函数还未支持该规则!")
         super(TargetPosTask, self).__init__()
         self._api = api
         self._account = account
